/* gvfs_local.c -- GVFS handler for local filesystem operations.

 * Copyright (C) 1999 Steve Hill <sjhill@plutonium.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <dirent.h>
#include <stdio.h>
#include <errno.h>
#include <glib.h>

#include "gvfs.h"
#include "gvfs_local.h"
#ifdef __DEBUG__
#include "debug.h"
#endif

gint
local_init (GVFS * gvfs)
{
  return 1;
}

void *
local_opendir (gchar * dirname)
{
  DIR *dir;

  if ((dir = opendir (dirname)) == NULL)
    return NULL;
  else
    return dir;
}

void *
local_readdir (void *gvfs_info)
{
  return readdir ((DIR *) gvfs_info);
}

gint
local_closedir (void *gvfs_info)
{
  return closedir ((DIR *) gvfs_info);
}

gint
local_stat (gchar * path, struct stat * buf)
{
  return stat (path, buf);
}

gint
local_lstat (gchar * path, struct stat * buf)
{
  return lstat (path, buf);
}

gint
local_unlink (gchar * filename)
{
  return unlink (filename);
}

gint
local_rm (gchar * filename)
{
  dbgprintf ("rm %s\n", filename);
  if (unlink (filename) == 0)
    return 0;
  else
    return errno;
}

gint
local_rmdir (gchar * filename)
{
  dbgprintf ("rmdir %s\n", filename);
  if (rmdir (filename) == 0)
    return 0;
  else
    return errno;
}

gint
local_symlink (gchar * sl_name, gchar * sl_target)
{
  dbgprintf ("symlinking %s to %s\n", sl_target, sl_name);
  if (symlink (sl_target, sl_name) == 0)
    return 0;
  else
    return errno;
}

gint
local_rename (gchar * from, gchar * to)
{
  dbgprintf ("rename from %s to %s\n", from, to);
  if (rename (from, to) == 0)
    return 0;
  else
    return errno;
}

gint
local_mkdir (gchar * filename)
{
  dbgprintf ("mkdir %s\n", filename);
  if (mkdir (filename, 493) == 0)
    return 0;
  else
    return errno;
}

gint
local_readlink (gchar * path, void *buf, gint bufsize)
{
  if (readlink (path, buf, bufsize) == 0)
    return 0;
  else
    return errno;
}

void *
local_fopen (gchar * filename, gchar * mode)
{
  return fopen (filename, mode);
}

gint
local_fclose (void *fd)
{
  return fclose ((FILE *) fd);
}

gint
local_fread (void *fd, void *buffer, gulong size)
{
  return fread (buffer, 1, size, (FILE *) fd);
}

gint
local_fwrite (void *fd, void *buffer, gulong size)
{
  return fwrite (buffer, 1, size, (FILE *) fd);
}

gint
local_chmod (gchar * filename, int mode)
{
  if (chmod (filename, mode) == 0)
    return 0;
  else
    return errno;
}

gint
local_chown (gint filename, int owner, int group)
{
  if (chown (filename, owner, group) == 0)
    return 0;
  else
    return errno;
}

GVFS gvfs_local_fs_ops =
{
  NULL,
  FALSE,
  local_init,
  local_opendir,
  local_readdir,
  local_closedir,
  local_stat,
  local_lstat,
  local_readlink,
  local_unlink,
  local_fopen,
  local_fclose,
  local_fread,
  local_fwrite,
  local_mkdir,
  local_rm,
  local_rmdir,
  local_symlink,
  local_rename,
  local_chmod,
  local_chown
};
